@@ -61,7 +61,7 @@ class MQTTWebsocket:
 
         def parse_float(result):
             if result["is_success"]:
-                for i in ["open", "high", "low", "close"]:
+                for i in ["open", "high", "low", "close", "value"]:
                     result["data"][i] = float(result["data"][i])
             return result
 
@@ -72,7 +72,7 @@ class MQTTWebsocket:
     def subscribe_price_info(self, symbol, on_message, args=()):
         def parse_float(result):
             if result["is_success"]:
-                for i in ["high", "low", "last", "projected_open_price"]:
+                for i in ["high", "low", "last", "projected_open_price", "change", "total_value"]:
                     result["data"][i] = float(result["data"][i])
             return result
 
